@@ -188,6 +188,7 @@ impl FeedbinApi {
     }
 
     // https://github.com/feedbin/feedbin-api/blob/master/content/entries.md#entries
+    #[allow(clippy::too_many_arguments)]
     pub async fn get_entries(
         &self,
         client: &Client,
@@ -196,6 +197,7 @@ impl FeedbinApi {
         ids: Option<&[EntryID]>,
         starred: Option<bool>,
         enclosure: Option<bool>,
+        extended: bool,
     ) -> Result<Vec<Entry>, ApiError> {
         let mut api_endpoint = String::from("/v2/entries.json");
         if page.is_some()
@@ -203,6 +205,7 @@ impl FeedbinApi {
             || ids.is_some()
             || starred.is_some()
             || enclosure.is_some()
+            || extended
         {
             api_endpoint.push('?');
         }
@@ -237,6 +240,17 @@ impl FeedbinApi {
             }
             api_endpoint.push_str(&format!("include_enclosure={}", enclosure));
         }
+        if extended {
+            if page.is_some()
+                || since.is_some()
+                || ids.is_some()
+                || starred.is_some()
+                || enclosure.is_some()
+            {
+                api_endpoint.push('&');
+            }
+            api_endpoint.push_str("mode=extended");
+        }
 
         match self.get(client, &api_endpoint, None).await? {
             CacheRequestResponse::Modified(CacheResult {
